pub fn init_flush_scheduler(sched: Rc<dyn ScheduleFlush>)Expand description
Set the platform flush scheduler and install the signal deferred- callback hook (idempotent — subsequent calls are no-ops for the hook).
pub fn init_flush_scheduler(sched: Rc<dyn ScheduleFlush>)Set the platform flush scheduler and install the signal deferred- callback hook (idempotent — subsequent calls are no-ops for the hook).