pub struct CallbackHandle { /* private fields */ }Expand description
Owns a resource that must be cleaned up when the owning TaskScope
is dropped.
Currently used for signal subscriptions registered by the bind_*
functions. When the TaskScope drops, every registered
CallbackHandle is dropped, which calls the stored cleanup closure
to unsubscribe from the signal.
Implementations